# deconz
Python library wrapping deconz rest api for home-assistant

Currently supports dimmable lights, motion sensors and switches

Generate an API key using utils.py/get_api_key, host, username and password are required parameters. Or follow snillevilla.se guide to get a key.

Only host address and API key are necessary for normal operations.

## Acknowledgements
* Mattias Flodins custom Deconz component was a great source of inspiration
* Maija Vilkina and her blog [Snillevilla](https://snillevilla.se/) has been a huge help in getting deCONZ up and running.